diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/ItemWriteListener.java b/spring-batch-core/src/main/java/org/springframework/batch/core/ItemWriteListener.java
index 951961f2a..69894a12f 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/ItemWriteListener.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/ItemWriteListener.java
@@ -33,10 +33,10 @@ public interface ItemWriteListener extends StepListener {
void beforeWrite(Object item);
/**
- * Called after {@link ItemWriter#write(Object) If the item is last in a
+ * Called after {@link ItemWriter#write(Object)} If the item is last in a
* chunk, this will be called before any transaction is committed, and
* before {@link ChunkListener#afterChunk()}
- * @param item TODO
+ * @param item written item
*/
void afterWrite(Object item);
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/JobExecution.java b/spring-batch-core/src/main/java/org/springframework/batch/core/JobExecution.java
index b6c7dec49..51d4a5dae 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/JobExecution.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/JobExecution.java
@@ -140,8 +140,6 @@ public class JobExecution extends Entity {
/**
* Register a step execution with the current job execution.
- *
- * @param stepExecution
*/
public StepExecution createStepExecution(Step step) {
StepExecution stepExecution = new StepExecution(step, this, null);
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/CommandLineJobRunner.java b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/CommandLineJobRunner.java
index 795a566f4..a433e00b9 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/CommandLineJobRunner.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/CommandLineJobRunner.java
@@ -140,7 +140,7 @@ public class CommandLineJobRunner {
}
/**
- * Injection setter for the {@link JvmExitCodeMapper}.
+ * Injection setter for the {@link ExitCodeMapper}.
*
* @param exitCodeMapper
* the exitCodeMapper to set
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/ExitCodeMapper.java b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/ExitCodeMapper.java
index 0ebf41a38..a936d81b3 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/ExitCodeMapper.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/ExitCodeMapper.java
@@ -6,7 +6,6 @@ package org.springframework.batch.core.launch.support;
* framework has specific requirements regarding the operating system process
* return status.
*
- * @param The type of return status expected by the environment
* @author Stijn Maller
* @author Lucas Ward
* @author Dave Syer
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/SimpleJobLauncher.java b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/SimpleJobLauncher.java
index bcdb742e9..6e6aca4fb 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/SimpleJobLauncher.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/SimpleJobLauncher.java
@@ -62,8 +62,8 @@ public class SimpleJobLauncher implements JobLauncher, InitializingBean {
* used to determine if this is an execution of an existing job instance, or if a new one should
* be created.
*
- * @param job, the job to be run.
- * @param jobParameters, the {@link JobParameters} for this particular execution.
+ * @param job the job to be run.
+ * @param jobParameters the {@link JobParameters} for this particular execution.
* @return JobExecutionAlreadyRunningException if the JobInstance already exists and has an
* execution already running.
* @throws JobRestartException if the execution would be a re-start, but a re-start is either
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/SystemExiter.java b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/SystemExiter.java
index 71e10e0b8..778ed3f1e 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/SystemExiter.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/SystemExiter.java
@@ -33,7 +33,7 @@ public interface SystemExiter {
* @throws SecurityException
* if a security manager exists and its checkExit
* method doesn't allow exit with the specified status.
- * @see System.exit
+ * @see System#exit(int)
*/
void exit(int status);
}
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeChunkListener.java b/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeChunkListener.java
index aa4fd80d1..71a41558a 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeChunkListener.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeChunkListener.java
@@ -42,7 +42,7 @@ public class CompositeChunkListener implements ChunkListener {
/**
* Register additional listener.
*
- * @param stepListener
+ * @param chunkListener
*/
public void register(ChunkListener chunkListener) {
if (!listeners.contains(chunkListener)) {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeSkipListener.java b/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeSkipListener.java
index 62604535b..84ea66cab 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeSkipListener.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/listener/CompositeSkipListener.java
@@ -42,7 +42,7 @@ public class CompositeSkipListener implements SkipListener {
/**
* Register additional listener.
*
- * @param stepExecutionListener
+ * @param listener
*/
public void register(SkipListener listener) {
if (!listeners.contains(listener)) {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/listener/MulticasterBatchListener.java b/spring-batch-core/src/main/java/org/springframework/batch/core/listener/MulticasterBatchListener.java
index 624831dc8..8c09068c0 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/listener/MulticasterBatchListener.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/listener/MulticasterBatchListener.java
@@ -86,8 +86,7 @@ public class MulticasterBatchListener implements StepExecutionListener, ChunkLis
}
/**
- * @return
- * @see org.springframework.batch.core.listener.CompositeStepExecutionListener#afterStep()
+ * @see org.springframework.batch.core.listener.CompositeStepExecutionListener#afterStep(StepExecution)
*/
public ExitStatus afterStep(StepExecution stepExecution) {
return stepListener.afterStep(stepExecution);
@@ -103,8 +102,7 @@ public class MulticasterBatchListener implements StepExecutionListener, ChunkLis
/**
* @param e
- * @return
- * @see org.springframework.batch.core.listener.CompositeStepExecutionListener#onErrorInStep(java.lang.Throwable)
+ * @see org.springframework.batch.core.listener.CompositeStepExecutionListener#onErrorInStep(StepExecution, Throwable)
*/
public ExitStatus onErrorInStep(StepExecution stepExecution, Throwable e) {
return stepListener.onErrorInStep(stepExecution, e);
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/JobRepository.java b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/JobRepository.java
index 330346f7e..0b6ea5c13 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/JobRepository.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/JobRepository.java
@@ -72,7 +72,7 @@ public interface JobRepository {
* Preconditions: {@link JobExecution} must contain a valid
* {@link JobInstance}.
*
- * @param jobInstance
+ * @param jobExecution
*/
void saveOrUpdate(JobExecution jobExecution);
@@ -83,11 +83,11 @@ public interface JobRepository {
* Instead, it should be left blank, to be assigned by a
* {@link JobRepository}. The {@link ExecutionContext} of the
* {@link StepExecution} is not saved: see
- * {@link #saveExecutionContext(StepExecution)}.
+ * {@link #saveOrUpdateExecutionContext(StepExecution)}.
*
* Preconditions: {@link StepExecution} must have a valid {@link Step}.
*
- * @param jobInstance
+ * @param stepExecution
*/
void saveOrUpdate(StepExecution stepExecution);
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/AbstractJdbcBatchMetadataDao.java b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/AbstractJdbcBatchMetadataDao.java
index 22cd58b60..5f5fcfcc5 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/AbstractJdbcBatchMetadataDao.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/AbstractJdbcBatchMetadataDao.java
@@ -29,7 +29,7 @@ public abstract class AbstractJdbcBatchMetadataDao implements InitializingBean {
/**
* Public setter for the table prefix property. This will be prefixed to all
* the table names before queries are executed. Defaults to
- * {@value #DEFAULT_TABLE_PREFIX}.
+ * {@link #DEFAULT_TABLE_PREFIX}.
*
* @param tablePrefix the tablePrefix to set
*/
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcJobExecutionDao.java b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcJobExecutionDao.java
index a7317ef8a..82e6211ae 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcJobExecutionDao.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcJobExecutionDao.java
@@ -64,7 +64,7 @@ public class JdbcJobExecutionDao extends AbstractJdbcBatchMetadataDao implements
}
/**
- * @see JobDao#getJobExecutionCount(JobInstance)
+ * @see JobExecutionDao#getJobExecutionCount(JobInstance)
* @throws IllegalArgumentException if jobId is null.
*/
public int getJobExecutionCount(JobInstance jobInstance) {
@@ -82,7 +82,7 @@ public class JdbcJobExecutionDao extends AbstractJdbcBatchMetadataDao implements
* abstraction. Once a new id has been obtained, the JobExecution is saved
* via a SQL INSERT statement.
*
- * @see JobDao#saveJobExecution(JobExecution)
+ * @see JobExecutionDao#saveJobExecution(JobExecution)
* @throws IllegalArgumentException if jobExecution is null, as well as any
* of it's fields to be persisted.
*/
@@ -124,7 +124,7 @@ public class JdbcJobExecutionDao extends AbstractJdbcBatchMetadataDao implements
* ID. The database is then queried to ensure that the ID exists, which
* ensures that it is valid.
*
- * @see JobDao#updateJobExecution(JobExecution)
+ * @see JobExecutionDao#updateJobExecution(JobExecution)
*/
public void updateJobExecution(JobExecution jobExecution) {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcJobInstanceDao.java b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcJobInstanceDao.java
index 3e89adb6a..2cd9a57a0 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcJobInstanceDao.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcJobInstanceDao.java
@@ -47,8 +47,8 @@ public class JdbcJobInstanceDao extends AbstractJdbcBatchMetadataDao implements
* jobIncrementer (which is likely a sequence) for the nextLong, and then
* passing the Id and parameter values into an INSERT statement.
*
- * @see JobDao#createJob(JobIdentifier)
- * @throws IllegalArgumentException if any {@link JobIdentifier} fields are
+ * @see JobInstanceDao#createJobInstance(Job, JobParameters)
+ * @throws IllegalArgumentException if any {@link JobParameters} fields are
* null.
*/
public JobInstance createJobInstance(Job job, JobParameters jobParameters) {
@@ -159,8 +159,8 @@ public class JdbcJobInstanceDao extends AbstractJdbcBatchMetadataDao implements
* The job table is queried for any jobs that match the
* given identifier, adding them to a list via the RowMapper callback.
*
- * @see JobDao#findJobInstances(JobIdentifier)
- * @throws IllegalArgumentException if any {@link JobIdentifier} fields are
+ * @see JobInstanceDao#getJobInstance(Job, JobParameters)
+ * @throws IllegalArgumentException if any {@link JobParameters} fields are
* null.
*/
public JobInstance getJobInstance(final Job job, final JobParameters jobParameters) {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcStepExecutionDao.java b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcStepExecutionDao.java
index 086934316..57f7eb6dc 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcStepExecutionDao.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JdbcStepExecutionDao.java
@@ -168,7 +168,7 @@ public class JdbcStepExecutionDao extends AbstractJdbcBatchMetadataDao implement
* stepExecutionIncrementor, and then set in the StepExecution. All values
* will then be stored via an INSERT statement.
*
- * @see StepDao#saveStepExecution(StepExecution)
+ * @see StepExecutionDao#saveStepExecution(StepExecution)
*/
public void saveStepExecution(StepExecution stepExecution) {
@@ -213,7 +213,7 @@ public class JdbcStepExecutionDao extends AbstractJdbcBatchMetadataDao implement
* any attributes that don't match a provided type must be serialized into a
* blob.
*
- * @see {@link LobCreator}
+ * @see LobCreator
*/
public void saveOrUpdateExecutionContext(final StepExecution stepExecution) {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JobInstanceDao.java b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JobInstanceDao.java
index 23fe75bc3..765344127 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JobInstanceDao.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/dao/JobInstanceDao.java
@@ -18,10 +18,10 @@ public interface JobInstanceDao {
*
* PreConditions: JobInstance for given name and parameters must not already exist
*
- * PostConditions: A valid job instancewill be returned which has been persisted and
+ * PostConditions: A valid job instance will be returned which has been persisted and
* contains an unique Id.
*
- * @param jobName
+ * @param job
* @param jobParameters
* @return JobInstance
*/
@@ -32,10 +32,10 @@ public interface JobInstanceDao {
* matching job instances are found, then a list of size 0 will be
* returned.
*
- * @param jobName
+ * @param job
* @param jobParameters
- * @return List of {@link JobInstance} objects matching
- * {@link JobIdentifier}
+ * @return {@link JobInstance} object matching
+ * {@link Job} and {@link JobParameters}
*/
JobInstance getJobInstance(Job job, JobParameters jobParameters);
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/support/SimpleJobRepository.java b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/support/SimpleJobRepository.java
index f714d7765..5f615dba3 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/repository/support/SimpleJobRepository.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/repository/support/SimpleJobRepository.java
@@ -127,9 +127,10 @@ public class SimpleJobRepository implements JobRepository {
* the same {@link JobParameters} and job name). The first transaction to
* complete in this scenario obtains a valid {@link JobExecution}, and
* others throw {@link JobExecutionAlreadyRunningException} (or timeout).
- * There are no such guarantees if the {@link JobDao} does not respect the
- * transaction isolation levels (e.g. if using a non-relational data-store,
- * or if the platform does not support the higher isolation levels).
+ * There are no such guarantees if the {@link JobInstanceDao} and
+ * {@link JobExecutionDao} do not respect the transaction isolation levels
+ * (e.g. if using a non-relational data-store, or if the platform does not
+ * support the higher isolation levels).
*
Exception
+ * @param exceptionClasses defaults to Exception
*/
public void setSkippableExceptionClasses(Class[] exceptionClasses) {
this.skippableExceptionClasses = exceptionClasses;
@@ -127,7 +127,7 @@ public class SkipLimitStepFactoryBean extends SimpleStepFactoryBean {
}
/**
- * Uses the {@link #skipLimit} value to configure item handler and and
+ * Uses the {@link #setSkipLimit(int)} value to configure item handler and and
* exception handler.
*/
protected void applyConfiguration(ItemOrientedStep step) {
@@ -173,9 +173,6 @@ public class SkipLimitStepFactoryBean extends SimpleStepFactoryBean {
step.setItemHandler(itemHandler);
}
- /**
- * @return
- */
public void addFatalExceptionIfMissing(Class cls) {
List fatalExceptionList = new ArrayList(Arrays.asList(fatalExceptionClasses));
if (!fatalExceptionList.contains(cls)) {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/StatefulRetryStepFactoryBean.java b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/StatefulRetryStepFactoryBean.java
index f57255d3b..9f2b46de3 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/StatefulRetryStepFactoryBean.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/StatefulRetryStepFactoryBean.java
@@ -176,8 +176,8 @@ public class StatefulRetryStepFactoryBean extends SkipLimitStepFactoryBean {
/**
* @param itemReader
* @param itemWriter
- * @param retryCallback
* @param retryTemplate
+ * @param itemKeyGenerator
* @param itemRecoverer
*/
public StatefulRetryItemHandler(ItemReader itemReader, ItemWriter itemWriter, RetryOperations retryTemplate,
diff --git a/spring-batch-core/src/test/java/org/springframework/batch/core/JobInstanceTests.java b/spring-batch-core/src/test/java/org/springframework/batch/core/JobInstanceTests.java
index 234de669e..17fac5753 100644
--- a/spring-batch-core/src/test/java/org/springframework/batch/core/JobInstanceTests.java
+++ b/spring-batch-core/src/test/java/org/springframework/batch/core/JobInstanceTests.java
@@ -28,7 +28,7 @@ public class JobInstanceTests extends TestCase {
private JobInstance instance = new JobInstance(new Long(11), new JobParameters(), new JobSupport("job"));
/**
- * Test method for {@link org.springframework.batch.core.JobInstance#getIdentifier()}.
+ * Test method for {@link org.springframework.batch.core.JobInstance#getJobName()}.
*/
public void testGetName() {
instance = new JobInstance(new Long(1), new JobParameters(), new JobSupport("foo"));
diff --git a/spring-batch-core/src/test/java/org/springframework/batch/core/listener/CompositeJobExecutionListenerTests.java b/spring-batch-core/src/test/java/org/springframework/batch/core/listener/CompositeJobExecutionListenerTests.java
index 55a434ebe..9ed4de4f7 100644
--- a/spring-batch-core/src/test/java/org/springframework/batch/core/listener/CompositeJobExecutionListenerTests.java
+++ b/spring-batch-core/src/test/java/org/springframework/batch/core/listener/CompositeJobExecutionListenerTests.java
@@ -57,7 +57,7 @@ public class CompositeJobExecutionListenerTests extends TestCase {
/**
* Test method for
- * {@link org.springframework.batch.core.listener.CompositeExecutionJobListener#registerJobExecutionListener(org.springframework.batch.core.JobExecutionListener)}.
+ * {@link org.springframework.batch.core.listener.CompositeExecutionJobListener#register(org.springframework.batch.core.JobExecutionListener)}.
*/
public void testSetListener() {
listener.register(new JobExecutionListenerSupport() {
diff --git a/spring-batch-core/src/test/java/org/springframework/batch/core/listener/CompositeStepExecutionListenerTests.java b/spring-batch-core/src/test/java/org/springframework/batch/core/listener/CompositeStepExecutionListenerTests.java
index c8ca65737..c5a268cc1 100644
--- a/spring-batch-core/src/test/java/org/springframework/batch/core/listener/CompositeStepExecutionListenerTests.java
+++ b/spring-batch-core/src/test/java/org/springframework/batch/core/listener/CompositeStepExecutionListenerTests.java
@@ -59,7 +59,7 @@ public class CompositeStepExecutionListenerTests extends TestCase {
/**
* Test method for
- * {@link org.springframework.batch.core.listener.CompositeStepExecutionListener#registerJobExecutionListener(org.springframework.batch.core.StepExecutionListener)}.
+ * {@link org.springframework.batch.core.listener.CompositeStepExecutionListener#register(org.springframework.batch.core.StepExecutionListener)}.
*/
public void testSetListener() {
listener.register(new StepExecutionListenerSupport() {
diff --git a/spring-batch-core/src/test/java/org/springframework/batch/core/step/ThreadStepInterruptionPolicyTests.java b/spring-batch-core/src/test/java/org/springframework/batch/core/step/ThreadStepInterruptionPolicyTests.java
index 123f98f61..254a0c1ec 100644
--- a/spring-batch-core/src/test/java/org/springframework/batch/core/step/ThreadStepInterruptionPolicyTests.java
+++ b/spring-batch-core/src/test/java/org/springframework/batch/core/step/ThreadStepInterruptionPolicyTests.java
@@ -30,7 +30,7 @@ public class ThreadStepInterruptionPolicyTests extends TestCase {
private StepExecution context = new StepExecution(new StepSupport(), null);
/**
- * Test method for {@link org.springframework.batch.core.executor.interrupt.ThreadStepInterruptionPolicy#checkInterrupted(StepExecution)}.
+ * Test method for {@link org.springframework.batch.core.step.ThreadStepInterruptionPolicy#checkInterrupted(StepExecution)}.
* @throws Exception
*/
public void testCheckInterruptedNotComplete() throws Exception {
@@ -39,7 +39,7 @@ public class ThreadStepInterruptionPolicyTests extends TestCase {
}
/**
- * Test method for {@link org.springframework.batch.core.executor.interrupt.ThreadStepInterruptionPolicy#checkInterrupted(StepExecution)}.
+ * Test method for {@link org.springframework.batch.core.step.ThreadStepInterruptionPolicy#checkInterrupted(StepExecution)}.
* @throws Exception
*/
public void testCheckInterruptedComplete() throws Exception {
diff --git a/spring-batch-core/src/test/java/org/springframework/batch/core/step/item/SkipLimitStepFactoryBeanTests.java b/spring-batch-core/src/test/java/org/springframework/batch/core/step/item/SkipLimitStepFactoryBeanTests.java
index ede2e627a..85cbfbf81 100644
--- a/spring-batch-core/src/test/java/org/springframework/batch/core/step/item/SkipLimitStepFactoryBeanTests.java
+++ b/spring-batch-core/src/test/java/org/springframework/batch/core/step/item/SkipLimitStepFactoryBeanTests.java
@@ -315,7 +315,7 @@ public class SkipLimitStepFactoryBeanTests extends TestCase {
}
/**
- * @param commaDelimitedListToSet
+ * @param failures commaDelimitedListToSet
*/
public SkipWriterStub(Collection failures) {
this.failures = failures;
diff --git a/spring-batch-core/src/test/java/org/springframework/batch/core/step/tasklet/TaskletStepTests.java b/spring-batch-core/src/test/java/org/springframework/batch/core/step/tasklet/TaskletStepTests.java
index c7a33d495..0ffc51e3f 100644
--- a/spring-batch-core/src/test/java/org/springframework/batch/core/step/tasklet/TaskletStepTests.java
+++ b/spring-batch-core/src/test/java/org/springframework/batch/core/step/tasklet/TaskletStepTests.java
@@ -221,7 +221,6 @@ public class TaskletStepTests extends TestCase {
}
/**
- * @param b
* @param error
*/
public StubTasklet(Throwable error) {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/ExportedJobLauncher.java b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/ExportedJobLauncher.java
index 998771f46..be61fa125 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/ExportedJobLauncher.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/launch/support/ExportedJobLauncher.java
@@ -19,12 +19,13 @@ package org.springframework.batch.core.launch.support;
import java.util.Properties;
import org.springframework.batch.core.JobExecution;
+import org.springframework.batch.core.JobParameters;
import org.springframework.batch.core.launch.JobLauncher;
/**
* Interface to expose for remote management of jobs. Similar to
* {@link JobLauncher}, but replaces {@link JobExecution} and
* {@link JobIdentifier} with Strings in return types and method parameters, so
* it can be inspected by remote clients like the jconsole from the JRE without
* any links to Spring Batch.
*
@@ -19,12 +19,13 @@ package org.springframework.batch.core.launch.support;
* Interface to expose for remote management of jobs. Similar to
* {@link JobLauncher}, but replaces {@link JobExecution} and
- * {@link JobIdentifier} with Strings in return types and method parameters, so
+ * {@link JobParameters} with Strings in return types and method parameters, so
* it can be inspected by remote clients like the jconsole from the JRE without
* any links to Spring Batch.
diff --git a/spring-batch-core/src/test/java/org/springframework/batch/core/job/AbstractJobTests.java b/spring-batch-core/src/test/java/org/springframework/batch/core/job/AbstractJobTests.java
index c01fb355f..ad3895fd2 100644
--- a/spring-batch-core/src/test/java/org/springframework/batch/core/job/AbstractJobTests.java
+++ b/spring-batch-core/src/test/java/org/springframework/batch/core/job/AbstractJobTests.java
@@ -30,9 +30,9 @@ public class AbstractJobTests extends TestCase {
JobSupport job = new JobSupport("job");
/**
* Test method for {@link org.springframework.batch.core.job.AbstractJob#JobConfiguration()}.
*/
- public void testJobConfiguration() {
+ public void testGetName() {
job = new JobSupport();
assertNull(job.getName());
}
@@ -56,7 +56,7 @@ public class AbstractJobTests extends TestCase {
}
/**
- * Test method for {@link org.springframework.batch.core.job.AbstractJob#setStepNames(java.util.List)}.
+ * Test method for {@link org.springframework.batch.core.job.AbstractJob#setSteps(java.util.List)}.
*/
public void testSetSteps() {
job.setSteps(Collections.singletonList(new StepSupport("step")));
@@ -65,7 +65,7 @@ public class AbstractJobTests extends TestCase {
/**
* Test method for
- * {@link org.springframework.batch.core.job.AbstractJob#addStepName(org.springframework.batch.core.configuration.StepConfiguration)}.
+ * {@link org.springframework.batch.core.job.AbstractJob#addStep(org.springframework.batch.core.Step)}.
*/
public void testAddStep() {
job.addStep(new StepSupport("step"));
@@ -73,7 +73,7 @@ public class AbstractJobTests extends TestCase {
}
/**
- * Test method for {@link org.springframework.batch.core.job.AbstractJob#setStartLimit(int)}.
+ * Test method for {@link org.springframework.batch.core.job.JobSupport#setStartLimit(int)}.
*/
public void testSetStartLimit() {
assertEquals(Integer.MAX_VALUE, job.getStartLimit());
@@ -30,9 +30,9 @@ public class AbstractJobTests extends TestCase {
JobSupport job = new JobSupport("job");
/**
- * Test method for {@link org.springframework.batch.core.job.AbstractJob#JobConfiguration()}.
+ * Test method for {@link org.springframework.batch.core.job.AbstractJob#getName()}.
*/